require 'prettify/version'
require 'thor'
require 'json'
require 'colorize'

#
# This file contains the prettifier module and the CLI support code for this gem
# Author: Nayyara Samuel (nayyara.samuel@opower.com)
#
module Prettify

  module Prettifier
    def prettify(json)
      json_map = json.class == String ? JSON.parse(json) : json
      JSON.pretty_generate(json_map).gsub(/\[\n+\s*\]/, '[]')
    end
  end

  class Command < Thor
    include Prettifier

    desc 'json', 'Formats JSON files on the file system'
    option :location, aliases: '-l', required: true, desc: 'The desired file/directory containing the JSON files'
    option :output, aliases: '-o', required: false, desc: 'The desired output file/directory to write to'

    def json
      _options = options.dup
      _options['output'] = _options['location'] if !_options['output']

      puts "\nRunning with options:"
      _options.each do |k, v|
        puts "\t#{k}: #{v}".yellow
      end
      puts ''

      prettify_block = Proc.new do |read_file, write_file|
        puts "Processing file: #{File.basename(read_file)}".cyan
        content = File.read(read_file)
        content = prettify(content)
        f = File.open(write_file, 'w')
        f.write(content)
        f.close
      end

      location = _options['location']
      output = _options['output']
      if File.directory?(location)
        raise 'Output location must be a directory' unless File.directory?(output)
        Dir.glob(File.join(location, '*.json')) do |file|
          prettify_block.call(file, File.join(output, File.basename(file)))
        end
      else
        output = File.directory?(output) ? File.join(output, location) : output
        prettify_block.call(location, output)
      end

      puts ''
    end
  end

end
